@@ -13,13 +13,12 @@ import os.path
 import platform
 import re
 import signal
-import site
 import stat
 import sys
 import textwrap
 
 from pathlib import Path
-from typing import Any, Iterable
+from typing import Any
 
 import pytest
 
@@ -1144,9 +1143,6 @@ class ExcepthookTest(CoverageTest):
         # executed.
         data = coverage.CoverageData()
         data.read()
-        print(f"{line_counts(data) = }")
-        print(f"{data = }")
-        print("data.lines excepthook.py:", data.lines(os.path.abspath("excepthook.py")))
         assert line_counts(data)["excepthook.py"] == 7
 
     @pytest.mark.skipif(
@@ -1210,6 +1206,7 @@ class AliasedCommandTest(CoverageTest):
         # "coverage3" works on py3
         cmd = "coverage%d" % sys.version_info[0]
         out = self.run_command(cmd)
+        assert "deprecated" in out
         assert "Code coverage for Python" in out
 
     def test_wrong_alias_doesnt_work(self) -> None:
@@ -1224,6 +1221,7 @@ class AliasedCommandTest(CoverageTest):
         # "coverage-3.9" works on py3.9
         cmd = "coverage-%d.%d" % sys.version_info[:2]
         out = self.run_command(cmd)
+        assert "deprecated" in out
         assert "Code coverage for Python" in out
 
     @pytest.mark.parametrize(
@@ -1374,7 +1372,6 @@ class YankedDirectoryTest(CoverageTest):
 
 
 @pytest.mark.skipif(env.METACOV, reason="Can't test subprocess pth file during metacoverage")
-@pytest.mark.xdist_group(name="needs_pth")
 class ProcessStartupTest(CoverageTest):
     """Test that we can measure coverage in subprocesses."""
 
@@ -1393,9 +1390,9 @@ class ProcessStartupTest(CoverageTest):
         self.make_file(
             "sub.py",
             """\
-            f = open("out.txt", "w", encoding="utf-8")
-            f.write("Hello, world!\\n")
-            f.close()
+            with open("out.txt", "w", encoding="utf-8") as f:
+                f.write("Hello, world!\\n")
+            a = 3
             """,
         )
 
@@ -1416,7 +1413,7 @@ class ProcessStartupTest(CoverageTest):
         assert line_counts(data)["main.py"] == 3
         assert line_counts(data)["sub.py"] == 3
 
-    def test_subprocess_with_pth_files(self, _create_pth_file: None) -> None:
+    def test_subprocess_with_pth_files(self) -> None:
         # An existing data file should not be read when a subprocess gets
         # measured automatically.  Create the data file here with bogus data in
         # it.
@@ -1444,7 +1441,7 @@ class ProcessStartupTest(CoverageTest):
         data.read()
         assert line_counts(data)["sub.py"] == 3
 
-    def test_subprocess_with_pth_files_and_parallel(self, _create_pth_file: None) -> None:
+    def test_subprocess_with_pth_files_and_parallel(self) -> None:
         # https://github.com/coveragepy/coveragepy/issues/492
         self.make_main_and_sub()
         self.make_file(
@@ -1595,30 +1592,7 @@ class ProcessStartupTest(CoverageTest):
             assert line_counts(data) == {"main.py": 5, "sub.py": 2, "other.py": 1}
 
 
-@pytest.fixture
-def _clean_pth_files() -> Iterable[None]:
-    """A fixture to clean up any .pth files we created during the test."""
-    # The execv test needs to make .pth files so that subprocesses will get
-    # measured.  But there's no way for coverage to remove those files because
-    # they need to exist when the new program starts, and there's no
-    # information carried over to clean them automatically.
-    #
-    # So for these tests, we clean them as part of the test suite.
-    pth_files: set[Path] = set()
-    for d in site.getsitepackages():
-        pth_files.update(Path(d).glob("*.pth"))
-
-    try:
-        yield
-    finally:
-        for d in site.getsitepackages():
-            for pth in Path(d).glob("*.pth"):
-                if pth not in pth_files:
-                    pth.unlink()
-
-
 @pytest.mark.skipif(env.WINDOWS, reason="patch=execv isn't supported on Windows")
-@pytest.mark.xdist_group(name="needs_pth")
 class ExecvTest(CoverageTest):
     """Test that we can measure coverage in subprocesses."""
 
@@ -1632,7 +1606,7 @@ class ExecvTest(CoverageTest):
             )
         ],
     )
-    def test_execv_patch(self, fname: str, _clean_pth_files: None) -> None:
+    def test_execv_patch(self, fname: str) -> None:
         self.make_file(
             ".coveragerc",
             """\
@@ -1713,13 +1687,11 @@ class ProcessStartupWithSourceTest(CoverageTest):
     @pytest.mark.parametrize("dashm", ["-m", ""])
     @pytest.mark.parametrize("package", ["pkg", ""])
     @pytest.mark.parametrize("source", ["main", "sub"])
-    @pytest.mark.xdist_group(name="needs_pth")
     def test_pth_and_source_work_together(
         self,
         dashm: str,
         package: str,
         source: str,
-        _create_pth_file: None,
     ) -> None:
         """Run the test for a particular combination of factors.
 
@@ -1763,9 +1735,9 @@ class ProcessStartupWithSourceTest(CoverageTest):
         self.make_file(
             path("sub.py"),
             """\
-            f = open("out.txt", "w", encoding="utf-8")
-            f.write("Hello, world!")
-            f.close()
+            with open("out.txt", "w", encoding="utf-8") as f:
+                f.write("Hello, world!")
+            a = 3
             """,
         )
         self.make_file(
